cidict - case insensitive dictionary type for Python
====================================================

Everyone needs it, but there is no package implementing it.
Every project rolls its own.

When I was thinking that I should write unit tests for mine, I extracted it
into a separate package.

This is a work in progress.

Tests
-----

Run with ``nose``.

.. image:: https://api.travis-ci.org/p/cidict.png
  :target: https://travis-ci.org/p/cidict

License
-------

Released under the 2 clause BSD license.

References
----------

- http://docs.python.org/2/library/stdtypes.html#mapping-types-dict
